# ig_api

This package provides both an APIs to interact either with ig.com (demo or real account) OR simulation using historical data.

Develop your bot, find it's performance on historical data, ship it into production!

